@@ -6,7 +6,6 @@
 # Python-AD is copyright (c) 2007 by the Python-AD authors. See the file
 # "AUTHORS" for a complete overview.
 
-from __future__ import absolute_import
 import time
 import errno
 import socket
@@ -15,8 +14,6 @@ import random
 
 from ..util import misc
 from . import asn1, ldap
-import six
-from six.moves import range
 
 
 SERVER_PDC = 0x1
@@ -62,8 +59,8 @@ class Decoder(object):
         netbios_domain = self._decode_rfc1035()
         netbios_hostname = self._decode_rfc1035()
         user = self._decode_rfc1035()
-        client_site = self._decode_rfc1035()
         server_site = self._decode_rfc1035()
+        client_site = self._decode_rfc1035()
         return Reply(type=type, flags=flags, domain_guid=domain_guid,
                      forest=forest, domain=domain, hostname=hostname,
                      netbios_domain=netbios_domain,
@@ -131,7 +128,7 @@ class Decoder(object):
 
     def _set_buffer(self, buffer):
         """Set the current buffer."""
-        if not isinstance(buffer, six.binary_type):
+        if not isinstance(buffer, bytes):
             raise Error('Buffer must be bytes.')
         self.m_buffer = buffer
 
@@ -263,7 +260,7 @@ class Client(object):
                 if not self.m_queries:
                     break
                 try:
-                    data, addr = self.m_socket.recvfrom(self._bufsize,  
+                    data, addr = self.m_socket.recvfrom(self._bufsize,
                                                         socket.MSG_DONTWAIT)
                 except socket.error as err:
                     error = err.args[0]
